@@ -28,15 +28,12 @@ labkey.importRows <- function(baseUrl=NULL, folderPath, schemaName, queryName, t
     if (missing(toImport)) stop (paste("A value must be specified for toImport."))
     if (nrow(toImport) == 0) stop (paste("toImport must contain at least one row."))
 
-    ## normalize the folder path
-    folderPath <- encodeFolderPath(folderPath)
-
     ## URL encode folder path, JSON encode post body (if not already encoded)
     toImport <- convertFactorsToStrings(toImport);
     params <- list(schemaName=schemaName, queryName=queryName, apiVersion=8.3)
     pbody <- jsonEncodeRowsAndParams(toImport, params, na)
 
-    myurl <- paste(baseUrl, "query", folderPath, "importRows.api", sep="")
+    myurl <- labkey.buildURL(baseUrl, "query", "importRows.api", folderPath)
 
     ## Execute via our standard POST function
     mydata <- labkey.post(myurl, pbody)
